@@ -705,109 +705,3 @@ def get_dropout_layer(dropout_rate, dropout_variant, dim=2):
         layer = Lambda(lambda x: tf.identity(x))
     return layer
 
-
-class Involution(tf.keras.layers.Layer):
-    """
-    Involution layer.
-
-    References
-    ----------
-    [1] Involution: Inverting the Inherence of Convolution for Visual 
-    Recognition (Li et al. 2021): https://arxiv.org/abs/2103.06255
-
-    Notes
-    -----
-    Adapted from: https://keras.io/examples/vision/involution/
-    """
-    def __init__(self, kernel_size, kernel_mininet_filters, group_number, stride=1, 
-                 reduction_ratio=1, name_sufix='', full_output=False):
-        super().__init__(name='Involution' + name_sufix)
-        # Initialize the parameters.
-        self.kernel_mininet_filters = kernel_mininet_filters
-        self.group_number = group_number
-        self.kernel_size = kernel_size
-        self.stride = stride
-        self.reduction_ratio = reduction_ratio
-        self.full_output = full_output
-
-    def build(self, input_shape):
-        # Get the shape of the input.
-
-        # print(self.name)
-
-        (_, height, width, num_channels) = input_shape
-
-        # Scale the height and width with respect to the strides.
-        height = height // self.stride
-        width = width // self.stride
-
-        # Define a layer that average pools the input tensor if stride is more than 1
-        self.stride_layer = (
-            tf.keras.layers.AveragePooling2D(pool_size=self.stride, strides=self.stride, padding="same")
-            if self.stride > 1
-            else tf.identity)
-        # Define the kernel generation layer
-        self.kernel_gen = tf.keras.Sequential([
-            tf.keras.layers.Conv2D(filters=self.kernel_mininet_filters // self.reduction_ratio, kernel_size=1),
-            tf.keras.layers.BatchNormalization(),
-            tf.keras.layers.ReLU(),
-            tf.keras.layers.Conv2D(filters=self.kernel_size * self.kernel_size * self.group_number, kernel_size=1)
-            ])
-        # Define reshape layers
-        self.kernel_reshape = tf.keras.layers.Reshape(
-            target_shape=(height, width, self.kernel_size * self.kernel_size, 1, self.group_number))
-        self.input_patches_reshape = tf.keras.layers.Reshape(
-            target_shape=(height, width, self.kernel_size * self.kernel_size,
-                num_channels // self.group_number, self.group_number))
-        self.output_reshape = tf.keras.layers.Reshape(target_shape=(height, width, num_channels))
-
-    def call(self, x):
-        # Generate the kernel with respect to the input tensor: B, H, W, K*K*G
-
-        # print(x.shape)
-
-        kernel_input = self.stride_layer(x)
-        kernel = self.kernel_gen(kernel_input)
-
-        # print(kernel.shape)
-
-        # reshape the kernel: B, H, W, K*K, 1, G
-        kernel = self.kernel_reshape(kernel)
-
-        # print(kernel.shape)
-
-        # Extract input patches: B, H, W, K*K*C
-        input_patches = tf.image.extract_patches(
-            images=x,
-            sizes=[1, self.kernel_size, self.kernel_size, 1],
-            strides=[1, self.stride, self.stride, 1],
-            rates=[1, 1, 1, 1],
-            padding="SAME")
-
-        # print(input_patches.shape)
-
-        # Reshape the input patches to align with later operations: B, H, W, K*K, C//G, G
-        input_patches = self.input_patches_reshape(input_patches)
-
-        # print(input_patches.shape)
-
-        # Compute the multiply-add operation of kernels and patches: B, H, W, K*K, C//G, G
-        output = tf.multiply(kernel, input_patches)
-        
-        # print(output.shape)
-        
-        # B, H, W, C//G, G
-        output = tf.reduce_sum(output, axis=3)
-
-        # print(output.shape)
-
-        # Reshape the output kernel: B, H, W, C
-        output = self.output_reshape(output)
-
-        # print(output.shape)
-
-        if self.full_output:
-            # Return the output tensor and the kernel.
-            return output, kernel
-        else:
-            return output
\ No newline at end of file
